import fs from "fs";
import path from "path";
import { ConfigError } from "./errors.js";
import { ValidOptions } from "./types.js";
const sanitizeId = (data) => {
    return {
        name: "test",
    };
};
const sanitizeConfig = (data) => {
    const config = {};
    if (!data.version)
        throw new ConfigError("no version specified in config");
    if (data.options) {
        config.options = {};
        Object.keys(data.options).forEach((option) => {
            if (!ValidOptions.includes(option))
                throw new ConfigError(`unrecognized option ${option}`);
            else {
                const optionKey = option;
                if (typeof config.options !== "undefined")
                    config.options[optionKey] = data.options[option];
            }
        });
    }
    if (data.ids) {
        config.ids = [];
        data.ids.forEach((id) => {
            const sanitizedId = sanitizeId(id);
            config.ids?.push(sanitizedId);
        });
    }
    return config;
};
export const parseConfig = () => {
    const config = path.join(process.cwd(), `c7.json`);
    try {
        const buf = fs.readFileSync(config);
        const data = JSON.parse(buf.toString());
        const sanitizedConfig = sanitizeConfig(data);
        return sanitizedConfig;
    }
    catch (err) {
        if (err.code === "ENOENT") {
            // no file, this is okay
            return {};
        }
        else {
            throw new ConfigError(`error reading config: ${err.message}`);
        }
    }
};
